@@ -1,7 +1,9 @@
 package Complete::Bash;
 
-our $DATE = '2019-12-18'; # DATE
-our $VERSION = '0.331'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2019-12-22'; # DATE
+our $DIST = 'Complete-Bash'; # DIST
+our $VERSION = '0.332'; # VERSION
 
 use 5.010001;
 use strict;
@@ -548,7 +550,7 @@ sub format_completion {
     my $words    = $hcomp->{words};
     my $as       = $hcomp->{as} // 'string';
     # 'escmode' key is deprecated (Complete 0.11-) and will be removed later
-    my $esc_mode = $hcomp->{esc_mode} // $hcomp->{escmode} // 'default';
+    my $esc_mode = $hcomp->{esc_mode} // $hcomp->{escmode} // $ENV{COMPLETE_BASH_DEFAULT_ESC_MODE} // 'default';
     my $path_sep = $hcomp->{path_sep};
 
     # we keep the original words (before formatted with summaries) when we want
@@ -762,7 +764,7 @@ Complete::Bash - Completion routines for bash shell
 
 =head1 VERSION
 
-This document describes version 0.331 of Complete::Bash (from Perl distribution Complete-Bash), released on 2019-12-18.
+This document describes version 0.332 of Complete::Bash (from Perl distribution Complete-Bash), released on 2019-12-22.
 
 =head1 DESCRIPTION
 
@@ -1163,6 +1165,10 @@ Return value:  (any)
 
 =head1 ENVIRONMENT
 
+=head2 COMPLETE_BASH_DEFAULT_ESC_MODE
+
+Str.
+
 =head2 COMPLETE_BASH_FZF
 
 Bool. Whether to pass large completion answer to fzf instead of directly passing
